.. highlight:: shell

============
Installation
============


Stable release
--------------

To install pytest-ngsfixtures, run this command in your terminal:

.. code-block:: console

    $ conda install -c percyfal pytest-ngsfixtures

This is the preferred method to install pytest-ngsfixtures, as it will
always install the most recent stable release.

.. _installation-from-sources:

From sources
------------

The sources for pytest-ngsfixtures can be downloaded from the `github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git@github.com:percyfal/pytest-ngsfixtures.git

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install

.. _installation-developer-mode:

Developer mode
--------------
    
To install in developer mode, issue

.. code-block:: console

    $ python setup.py develop

    
.. _github repo: https://github.com/percyfal/pytest-ngsfixtures

